Changelog
=========

1.1.0
-----

- Policy will keep track of all the permissions and raise PermissionNotFound when called with unknown permission (hvdklauw)

1.0.1
-----

- Pass the context to the get_identity (olegpidsadnyi)

1.0.0
-----

* Initial public release
